import argparse

from .feed import FeedList
from .show import show_articles, show_lists
from .utils import validate_rss_url


def cli():
    parser = argparse.ArgumentParser(prog='teader',
                                     description='A Feed Reader From Terminal')
    subparser = parser.add_subparsers(title='commands', dest='command')

    # Init commands
    init_parser = subparser.add_parser(
        'init', help='Initialize a list of subscriptions')

    # Add commands
    add_parser = subparser.add_parser('add', help='Add a new subscription')
    add_parser.add_argument('url', help='Feed URL you want to add')
    add_parser.add_argument('-c',
                            '--category',
                            default='uncategorized',
                            help='Category you want to add')

    # Show commands
    show_parser = subparser.add_parser('show', help='Show articles')
    show_parser.add_argument('-c',
                             '--category',
                             action='store_true',
                             help='Show articles by category')
    show_parser.add_argument('-s',
                             '--subscription',
                             action='store_true',
                             help='Show articles by subscription')

    # List commands
    list_parser = subparser.add_parser('list',
                                       help='Show a list of subscriptions')

    # Delete commands
    delete_parser = subparser.add_parser(
        'delete', help='Delete a category or cancel a subscription')
    delete_parser.add_argument('-c',
                               '--category',
                               action='store_true',
                               help='Category you want to delete')
    delete_parser.add_argument('-s',
                               '--subscription',
                               action='store_true',
                               help='Subscription you want to cancel')

    args = parser.parse_args()

    if args.command == 'init':
        FeedList().reset()

    if args.command == 'add':
        url = validate_rss_url(args.url)
        FeedList().add(url, args.category)

    if args.command == 'show':
        if args.category:
            subs = FeedList().show_category()
        elif args.subscription:
            subs = FeedList().show_subscription()
        else:
            subs = FeedList().show_all()

        show_articles(subs)

    if args.command == 'list':
        lists = FeedList().lists()
        show_lists(lists)

    if args.command == 'delete':
        if args.category:
            FeedList().delete()
        elif args.subscription:
            FeedList().cancel()
        else:
            parser.print_usage()

    if not args.command:
        parser.print_help()


if __name__ == '__main__':
    cli()
