import feedparser
from concurrent import futures

from .utils import format_time, yield_nsized_chunks


def parse_feed(url):
    d = feedparser.parse(url)
    return [(entry.title, entry.link, format_time(entry.updated_parsed))
            for entry in d.entries]


def get_articles(subs):
    e = futures.ThreadPoolExecutor()
    wait_for = [e.submit(parse_feed, url) for url in subs]
    results = [f.result() for f in futures.as_completed(wait_for)]
    # sort by updated time
    articles = sorted([f for result in results for f in result],
                      key=lambda article: article[2],
                      reverse=True)
    articles = yield_nsized_chunks(articles)
    return articles
