import sys
import webbrowser

from .parse import get_articles
from .utils import _select_message, when_updated


def select_article(articles, i=0):
    if i > len(articles) - 1:
        pass
    else:
        # Clear terminal screen
        # Ref: https://github.com/pallets/click/blob/master/src/click/termui.py
        sys.stdout.write("\033[2J\033[1;1H")

        paginate = f'[{i+1}-{len(articles)}]'
        print(f'\nLatest articles {paginate}\n')

        for n, article in enumerate(articles[i], 1):
            when = when_updated(article[2])
            print(f'{n:^3} {when:^10} {article[0]}')
        print()

        while True:
            try:
                msg = _select_message(articles, i)
                index = input(f'{msg}: ')

                if index == 'n':
                    # read next chunk
                    i = i + 1
                    select_article(articles, i)
                    break
                else:
                    try:
                        url = articles[i][int(index) - 1][1]
                    except IndexError:
                        print('ERROR: Input number is out of range')
                    except ValueError:
                        print(f'ERROR: {index} is not a valid integer')
                    else:
                        webbrowser.open(url)
            except KeyboardInterrupt:
                exit()


def show_articles(subs):
    if not subs:
        print('No subscriptions yet')
    else:
        articles = get_articles(subs)
        select_article(articles)


def show_lists(lists):
    if not lists:
        print('No subscriptions yet')
    else:
        for node in lists:
            name = node.attrib.get('text')
            url = node.attrib.get('xmlUrl')
            if name and url:
                print(f'    - {name:^3}')
            else:
                print(f'[{name}]')
