import time
import sys

from datetime import datetime

import feedparser


def validate_rss_url(url):
    d = feedparser.parse(url)
    if d['bozo'] == 1:
        print(f'ERROR: {url} is non-well-formed feed URL')
        sys.exit()
    else:
        return url


def format_time(updated):
    style = '%Y/%m/%d-%H:%M:%S'
    return datetime.strptime(time.strftime(style, updated), style)


def when_updated(updated):
    now = datetime.utcnow()
    between = now - updated
    day = between.days

    if day:
        if day >= 365:
            return f'{day // 365}y ago'
        if day == 1:
            return 'yesterday'
        return f'{day}d ago'
    else:
        minute, second = divmod(between.seconds, 60)
        hour, minute = divmod(minute, 60)

        if hour:
            return f'{hour}h ago'
        elif minute:
            return f'{minute}m ago'
        else:
            return f'{second}s ago'


def yield_nsized_chunks(chunks, n=30):
    return [chunks[i:i + n] for i in range(0, len(chunks), 30)]


def _select_message(articles, i):
    paginate = '[1{}]'.format(
        '-' + str(len(articles[i]) if len(articles[i]) > 1 else ''))
    msg = f'Choose an article {paginate} to open browser '
    msg += 'or press [n] to read more ' if len(
        articles[i]) == 30 and i < len(articles) - 1 else ''
    msg += 'or press [Ctrl+C] to exit'
    return msg
